/**
 * Copyright (c) 2015-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.mock;

import org.ow2.petals.jmx.api.api.exception.DeploymentServiceErrorException;

/**
 * A deployment order defining what to do when deploying a service assembly:
 * <ul>
 * <li>returning a deployment report,</li>
 * <li>or an error.</li>
 * </ul>
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class DeploymentOrder {

    private final String deploymentReport;

    private final DeploymentServiceErrorException error;

    public DeploymentOrder(final String deploymentReport) {
        this(deploymentReport, null);
    }

    public DeploymentOrder(final DeploymentServiceErrorException error) {
        this(null, error);
    }

    /*
     * Set to private because only one attribute can be set
     */
    private DeploymentOrder(final String deploymentReport, final DeploymentServiceErrorException error) {
        this.deploymentReport = deploymentReport;
        this.error = error;
    }

    public String getDeploymentReport() {
        return this.deploymentReport;
    }

    public DeploymentServiceErrorException getError() {
        return this.error;
    }

}
