/**
 * Copyright (c) 2015-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.mock.junit;

import org.ow2.petals.jmx.api.api.ComponentClient;
import org.ow2.petals.jmx.api.api.configuration.component.RuntimeConfigurationComponentClient;
import org.ow2.petals.jmx.api.api.configuration.component.exception.ConfigurationComponentDoesNotExistException;
import org.ow2.petals.jmx.api.api.exception.ComponentErrorException;
import org.ow2.petals.jmx.api.api.exception.ComponentUnsupportedOperationException;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.ComponentMonitoringServiceClient;
import org.ow2.petals.jmx.api.mock.junit.PetalsJmxApiJunitRule.ComponentType;

/**
 * Mock of {@link ComponentClientMockItf}
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ComponentClientMock implements ComponentClientMockItf {

    private final String componentName;

    private final ComponentType componentType;

    private final RuntimeConfigurationComponentClient runtimeConfigurationComponentClient;

    private final Object runtimeConfigurationMock;

    private final ComponentMonitoringServiceClient monitoringServiceClient;

    private State currentState;

    /**
     * Is the method {@link ComponentClient#reloadConfiguration()} throws {@link ComponentUnsupportedOperationException}
     * ?
     */
    private boolean isUnsupportedReloadConfiguration = false;

    public ComponentClientMock(final String componentName, final ComponentType componentType) {
        this(componentName, componentType, State.SHUTDOWN, null, null, null);
    }

    public ComponentClientMock(final String componentName, final ComponentType componentType, final State currentState,
            final RuntimeConfigurationComponentClient runtimeConfigurationComponentClient,
            final Object runtimeConfigurationMock, final ComponentMonitoringServiceClient monitoringServiceClient) {
        this.componentName = componentName;
        this.componentType = componentType;
        this.currentState = currentState;
        this.runtimeConfigurationComponentClient = runtimeConfigurationComponentClient;
        this.runtimeConfigurationMock = runtimeConfigurationMock;
        this.monitoringServiceClient = monitoringServiceClient;
    }

    @Override
    public void start() throws ComponentErrorException {
        this.currentState = State.STARTED;
    }

    @Override
    public void stop() throws ComponentErrorException {
        this.currentState = State.STOPPED;
    }

    @Override
    public void shutdown() throws ComponentErrorException {
        this.currentState = State.SHUTDOWN;
    }

    @Override
    public State getCurrentState() throws ComponentErrorException {
        return this.currentState;
    }

    @Override
    public void reloadConfiguration() throws ComponentUnsupportedOperationException, ComponentErrorException {
        if (this.isUnsupportedReloadConfiguration) {
            throw new ComponentUnsupportedOperationException("reloadConfiguration");
        }
    }

    @Override
    public String getIdentifier() {
        return this.componentName;
    }

    @Override
    public ComponentType getType() {
        return this.componentType;
    }

    @Override
    public ComponentClientMockItf withUnsupportedReloadConfiguration() {
        this.isUnsupportedReloadConfiguration = true;
        return this;
    }

    @Override
    public ComponentMonitoringServiceClient getMonitoringServiceClient() {
        return this.monitoringServiceClient;
    }

    @Override
    public RuntimeConfigurationComponentClient getRuntimeConfigurationClient()
            throws ConfigurationComponentDoesNotExistException {
        return this.runtimeConfigurationComponentClient;
    }

    @Override
    public <T> T getRuntimeConfigurationClient(Class<T> clazz) throws ConfigurationComponentDoesNotExistException {
        assert clazz.isInstance(this.runtimeConfigurationMock);
        return (T) this.runtimeConfigurationMock;
    }
}