/**
 * Copyright (c) 2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.mock.junit;

import javax.management.ObjectName;

import org.ow2.petals.jmx.api.api.configuration.component.InstallationConfigurationComponentClient;
import org.ow2.petals.jmx.api.api.configuration.component.exception.ConfigurationComponentDoesNotExistException;
import org.ow2.petals.jmx.api.api.configuration.component.exception.ConfigurationComponentErrorException;
import org.ow2.petals.jmx.api.api.exception.InstallerComponentErrorException;
import org.ow2.petals.jmx.api.mock.junit.PetalsJmxApiJunitRule.ComponentType;

/**
 * Mock of {@link ComponentInstallerClientMockItf}
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ComponentInstallerClientMock implements ComponentInstallerClientMockItf {

    private final String componentName;

    private final ComponentType componentType;

    private final InstallationConfigurationComponentClient installationConfigurationComponentClient;

    private final Object installationConfigurationMock;

    public ComponentInstallerClientMock(final String componentName, final ComponentType componentType) {
        this(componentName, componentType, null, null);
    }

    public ComponentInstallerClientMock(final String componentName, final ComponentType componentType,
            final InstallationConfigurationComponentClient installationConfigurationComponentClient,
            final Object installationConfigurationMock) {
        this.componentName = componentName;
        this.componentType = componentType;
        this.installationConfigurationComponentClient = installationConfigurationComponentClient;
        this.installationConfigurationMock = installationConfigurationMock;
    }

    @Override
    public String getIdentifier() {
        return this.componentName;
    }

    @Override
    public ComponentType getType() {
        return this.componentType;
    }

    @Override
    public InstallationConfigurationComponentClient getInstallationConfigurationClient()
            throws ConfigurationComponentDoesNotExistException, ConfigurationComponentErrorException,
            InstallerComponentErrorException {
        return this.installationConfigurationComponentClient;
    }

    @Override
    public <T> T getInstallationConfigurationClient(Class<T> clazz) throws ConfigurationComponentDoesNotExistException,
            InstallerComponentErrorException {
        assert clazz.isInstance(this.installationConfigurationMock);
        return (T) this.installationConfigurationMock;
    }

    @Override
    public void install() throws InstallerComponentErrorException {
        // NOP
    }

    @Override
    public void uninstall() throws InstallerComponentErrorException {
        // NOP
    }

    @Override
    public boolean isInstalled() throws InstallerComponentErrorException {
        return false;
    }

    @Override
    public String getInstallRoot() throws InstallerComponentErrorException {
        return null;
    }

    @Override
    public ObjectName getMBeanName() {
        return null;
    }
}
