/**
 * Copyright (c) 2014-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.mock.junit;

import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

import javax.management.MBeanServer;

import org.ow2.petals.jmx.api.api.JMXClient;
import org.ow2.petals.jmx.api.api.exception.ConnectionErrorException;
import org.ow2.petals.jmx.api.api.exception.NotRemoteJMXClientException;

/**
 * <p>
 * The {@link PetalsJmxApiFactory} needed to {@link PetalsJmxApiJunitRule}
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class PetalsJmxApiFactory extends org.ow2.petals.jmx.api.api.PetalsJmxApiFactory {

    private Map<JMXClient, OnConnectionHandler> jmxClients = new HashMap<JMXClient, OnConnectionHandler>();

    public void registerJmxClient(final JMXClient jmxClient, final OnConnectionHandler onConnectionHandler) {
        this.jmxClients.put(jmxClient, onConnectionHandler);
    }

    public void deregisterJmxClients() {
        this.jmxClients.clear();
    }

    @Override
    public JMXClient createJMXClient(final String host, final Integer jndiPort,
            final String username, final String password)
            throws ConnectionErrorException {

        try {
            if (this.jmxClients.isEmpty()) {
                throw new ConnectionErrorException("No JMX Client registered");
            } else {
                for (final Entry<JMXClient, OnConnectionHandler> entry : this.jmxClients.entrySet()) {
                    final JMXClient jmxClient = entry.getKey();
                    if (jmxClient.getHost().getHostName().equals(host) && jmxClient.getPort() == jndiPort.intValue()
                            && ((jmxClient.getUsername() == null && username == null)
                                    || (jmxClient.getUsername() != null && jmxClient.getUsername().equals(username)))) {
                        if (entry.getValue().onConnection()) {
                            // The connection succeeds
                            return jmxClient;
                        } else {
                            // The connection fails
                            // NOP: an exception should occur on 'OnConnectionHandler.onConnection()'
                        }
                    }
                }
                // Here no registered JMX client was found
                throw new ConnectionErrorException(
                        "Unable to establish a pseudo-connection: no registered JMX client found");
            }
        } catch (final NotRemoteJMXClientException e) {
            throw new ConnectionErrorException(e);
        }

    }

    @Override
    public JMXClient createJMXClient(final MBeanServer mbeanServer) throws ConnectionErrorException {
        throw new ConnectionErrorException("Error creating the JMX client, no supported operation.");
    }

}
