/**
 * Copyright (c) 2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.mock.junit;

import java.io.ByteArrayOutputStream;
import java.math.BigDecimal;

import org.ow2.petals.jbi.descriptor.JBIDescriptorException;
import org.ow2.petals.jbi.descriptor.original.JBIDescriptorBuilder;
import org.ow2.petals.jbi.descriptor.original.generated.Identification;
import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.jmx.api.api.DeploymentServiceClient.State;

/**
 * A service assembly bean
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ServiceAssembly {

    private final String name;

    private final State state;

    /**
     * Create a service assembly deployed and in state {@value State#STARTED}
     * 
     * @param name
     */
    public ServiceAssembly(final String name) {
        this(name, State.STARTED);
    }

    public ServiceAssembly(final String name, final State state) {
        this.name = name;
        this.state = state;
    }

    /**
     * @return The name of the shared library
     */
    public String getName() {
        return this.name;
    }

    public State getState() {
        return this.state;
    }

    public String getDescriptor() throws JBIDescriptorException {
        final Jbi jbiDescriptor = new Jbi();
        jbiDescriptor.setVersion(BigDecimal.valueOf(1.0));
        final org.ow2.petals.jbi.descriptor.original.generated.ServiceAssembly serviceAssembly = new org.ow2.petals.jbi.descriptor.original.generated.ServiceAssembly();
        jbiDescriptor.setServiceAssembly(serviceAssembly);

        final Identification identification = new Identification();
        identification.setName(this.name);
        identification.setDescription("");
        serviceAssembly.setIdentification(identification);

        final ByteArrayOutputStream jbiDescrOutputStream = new ByteArrayOutputStream();
        JBIDescriptorBuilder.getInstance().writeXMLJBIdescriptor(jbiDescriptor, jbiDescrOutputStream);
        return jbiDescrOutputStream.toString();
    }

    // Generated by Eclipse
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((name == null) ? 0 : name.hashCode());
        return result;
    }

    // Generated by Eclipse
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof ServiceAssembly)) {
            return false;
        }
        ServiceAssembly other = (ServiceAssembly) obj;
        if (name == null) {
            if (other.name != null) {
                return false;
            }
        } else if (!name.equals(other.name)) {
            return false;
        }
        return true;
    }
}
