/**
 * Copyright (c) 2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.mock.junit.monitoring.container.transporter.remote;

import java.util.HashMap;
import java.util.Map;

import org.ow2.petals.jmx.api.api.monitoring.container.transporter.remote.IncomingConnectionObjectPoolMetrics;
import org.ow2.petals.jmx.api.api.monitoring.container.transporter.remote.OutgoingConnectionObjectPoolMetrics;
import org.ow2.petals.jmx.api.api.monitoring.container.transporter.remote.TcpTransporterMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.container.transporter.remote.exception.TcpTransporterMonitoringServiceErrorException;

/**
 * A mock of {@link TcpTransporterMonitoringServiceClient} for unit testing
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class TcpTransporterMonitoringServiceClientMock implements TcpTransporterMonitoringServiceClient {

    private final Map<String, IncomingConnectionObjectPoolMetrics> incomingConnectionPoolMetrics = new HashMap<String, IncomingConnectionObjectPoolMetrics>();

    private final Map<String, OutgoingConnectionObjectPoolMetrics> outgoingConnectionPoolMetrics = new HashMap<String, OutgoingConnectionObjectPoolMetrics>();

    private final Map<String[], Long> deliveredOutgoingMessages = new HashMap<String[], Long>();

    private final Map<String[], Long> deliveredIncomingMessages = new HashMap<String[], Long>();

    public void addIncomingConnectionObjectPoolMetrics(final String containerName,
            final IncomingConnectionObjectPoolMetrics incomingConnectionObjectPoolMetrics) {
        this.incomingConnectionPoolMetrics.put(containerName, incomingConnectionObjectPoolMetrics);
    }

    public void addOutgoingConnectionObjectPoolMetrics(final String containerName,
            final OutgoingConnectionObjectPoolMetrics outgoingConnectionObjectPoolMetrics) {
        this.outgoingConnectionPoolMetrics.put(containerName, outgoingConnectionObjectPoolMetrics);
    }

    public void addDeliveredOutgoingMessagesMetrics(final String containerName, final String deliveryStatus,
            final int value) {
        this.deliveredOutgoingMessages.put(new String[] { containerName, deliveryStatus }, Long.valueOf(value));
    }

    public void addDeliveredIncomingMessagesMetrics(final String containerName, final String deliveryStatus,
            final int value) {
        this.deliveredIncomingMessages.put(new String[] { containerName, deliveryStatus }, Long.valueOf(value));
    }

    @Override
    public Map<String[], Long> getDeliveredOutgoingMessagesCount()
            throws TcpTransporterMonitoringServiceErrorException {
        return this.deliveredOutgoingMessages;
    }

    @Override
    public Map<String[], Long> getDeliveredIncomingMessagesCount()
            throws TcpTransporterMonitoringServiceErrorException {
        return this.deliveredIncomingMessages;
    }

    @Override
    public Map<String, OutgoingConnectionObjectPoolMetrics> getOutgoingConnectionPoolMetrics()
            throws TcpTransporterMonitoringServiceErrorException {
        return this.outgoingConnectionPoolMetrics;
    }

    @Override
    public Map<String, IncomingConnectionObjectPoolMetrics> getIncomingConnectionPoolMetrics()
            throws TcpTransporterMonitoringServiceErrorException {
        return this.incomingConnectionPoolMetrics;
    }

}
