/**
 * Copyright (c) 2013-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.mock.monitoring.component.soap;

import java.util.Map;

import org.ow2.petals.jmx.api.api.monitoring.component.framework.exception.ComponentMonitoringServiceErrorException;
import org.ow2.petals.jmx.api.api.monitoring.component.soap.IncomingWsRequestKey;
import org.ow2.petals.jmx.api.api.monitoring.component.soap.OutgoingWsRequestKey;
import org.ow2.petals.jmx.api.api.monitoring.component.soap.PetalsBcSoapMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.component.soap.WsClientPoolKey;
import org.ow2.petals.jmx.api.api.monitoring.object.ThreadPoolMetrics;
import org.ow2.petals.jmx.api.mock.junit.monitoring.object.ThreadPoolMetricsMock;
import org.ow2.petals.jmx.api.mock.monitoring.component.framework.ComponentMonitoringServiceClientMock;

/**
 * Mock of {@link PetalsBcSoapMonitoringServiceClient} for unit tests of application using the Petals JMX API.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class PetalsBcSoapMonitoringServiceClientMock extends ComponentMonitoringServiceClientMock
        implements PetalsBcSoapMonitoringServiceClient {

    /**
     * Value returns by the method {@link #getInformationHttpRequestsCount()}. Must be set by the unit test if needed.
     */
    public static Long INFORMATION_REQUEST_COUNT = null;

    /**
     * Value returns by the method {@link #getUnknownHttpRequestsCount()}. Must be set by the unit test if needed.
     */
    public static Long UNKNOWN_REQUEST_COUNT = null;

    /**
     * Value returns by the method {@link #getServiceContractsHttpRequestsCount()}. Must be set by the unit test if
     * needed.
     */
    public static Map<String, Long> SERVICE_CONTRACTS_REQUEST_COUNT = null;

    /**
     * Value returns by the method {@link #getIncomingWsRequestsCount()}. Must be set by the unit test if needed.
     */
    public static Map<IncomingWsRequestKey, Long> INCOMING_WS_REQUEST_COUNT = null;

    /**
     * Value returns by the method {@link #getIncomingWsRequestsResponseTimes()} . Must be set by the unit test if
     * needed.
     */
    public static Map<IncomingWsRequestKey, Long[]> INCOMING_WS_REQUEST_RESPONSE_TIMES = null;

    /**
     * Value returns by the method {@link #getIncomingWsRequestsResponseTimesGroupedBySvcAndExecStatus()} . Must be set
     * by the unit test if needed.
     */
    public static Map<IncomingWsRequestKey, Long[]> INCOMING_WS_REQUEST_RESPONSE_TIMES_GRP_BY_SVC_AND_STATUS = null;

    /**
     * Value returns by the method {@link #getOutgoingWsRequestsCount()}. Must be set by the unit test if needed.
     */
    public static Map<OutgoingWsRequestKey, Long> OUTGOING_WS_REQUEST_COUNT = null;

    /**
     * Value returns by the method {@link #getOutgoingWsRequestsResponseTimes()} . Must be set by the unit test if
     * needed.
     */
    public static Map<OutgoingWsRequestKey, Long[]> OUTGOING_WS_REQUEST_RESPONSE_TIMES = null;

    /**
     * Value returns by the method {@link #getOutgoingWsRequestsResponseTimesGroupedBySvcAndExecStatus()} . Must be set
     * by the unit test if needed.
     */
    public static Map<OutgoingWsRequestKey, Long[]> OUTGOING_WS_REQUEST_RESPONSE_TIMES_GRP_BY_SVC_AND_STATUS = null;

    /**
     * Value returns by the method {@link #getHttpServerThreadPoolMetrics()} for the max number of active threads of the
     * HTTP server. Must be set by the unit test if needed.
     */
    public static Long HTTP_SERVER_THREAD_POOL_ACTIVE_THREAD_MAX = null;

    /**
     * Value returns by the method {@link #getHttpServerThreadPoolMetrics()} for the current number of active threads of
     * the HTTP server. Must be set by the unit test if needed.
     */
    public static Long HTTP_SERVER_THREAD_POOL_ACTIVE_THREAD_CURRENT = null;

    /**
     * Value returns by the method {@link #getHttpServerThreadPoolMetrics()} for the max number of idle threads of the
     * HTTP server. Must be set by the unit test if needed.
     */
    public static Long HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX = null;

    /**
     * Value returns by the method {@link #getHttpServerThreadPoolMetrics()} for the current number of idle threads of
     * the HTTP server. Must be set by the unit test if needed.
     */
    public static Long HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT = null;

    /**
     * Value returns by the method {@link #getHttpServerThreadPoolMetrics()} for the max size of the HTTP server thread
     * pool. Must be set by the unit test if needed.
     */
    public static Long HTTP_SERVER_THREAD_POOL_MAX_SIZE = null;

    /**
     * Value returns by the method {@link #getHttpServerThreadPoolMetrics()} for the min size of the HTTP server thread
     * pool. Must be set by the unit test if needed.
     */
    public static Long HTTP_SERVER_THREAD_POOL_MIN_SIZE = null;

    /**
     * Value returns by the method {@link #getHttpServerThreadPoolMetrics()} for the current number of HTTP requests
     * waiting their processing by the HTTP server thread pool. Must be set by the unit test if needed.
     */
    public static Long HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT = null;

    /**
     * Value returns by the method {@link #getHttpServerThreadPoolMetrics()} for the max number of HTTP requests waiting
     * their processing by the HTTP server thread pool. Must be set by the unit test if needed.
     */
    public static Long HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX = null;

    public PetalsBcSoapMonitoringServiceClientMock(final String componentName) {
        super(componentName);
    }

    /**
     * {@inheritDoc}
     * 
     * <p>
     * Mock dedicated processing: If the component name is {@value #IDENTIFIER_FOR_COMPONENT_WITH_ERROR} the exception
     * {@link ComponentMonitoringServiceErrorException} is thrown with the message
     * {@value #ERROR_MESSAGE_GETTING_MONITORING_VALUES}. Otherwise the content of {@link #INCOMING_WS_REQUEST_COUNT} is
     * returned.
     * </p>
     */
    @Override
    public Map<IncomingWsRequestKey, Long> getIncomingWsRequestsCount()
            throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return INCOMING_WS_REQUEST_COUNT;
        }
    }

    /**
     * {@inheritDoc}
     * 
     * <p>
     * Mock dedicated processing: If the component name is {@value #IDENTIFIER_FOR_COMPONENT_WITH_ERROR} the exception
     * {@link ComponentMonitoringServiceErrorException} is thrown with the message
     * {@value #ERROR_MESSAGE_GETTING_MONITORING_VALUES}. Otherwise the content of {@link #INFORMATION_REQUEST_COUNT} is
     * returned.
     * </p>
     */
    @Override
    public Long getInformationHttpRequestsCount() throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(this.componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return INFORMATION_REQUEST_COUNT;
        }
    }

    /**
     * {@inheritDoc}
     * 
     * <p>
     * Mock dedicated processing: If the component name is {@value #IDENTIFIER_FOR_COMPONENT_WITH_ERROR} the exception
     * {@link ComponentMonitoringServiceErrorException} is thrown with the message
     * {@value #ERROR_MESSAGE_GETTING_MONITORING_VALUES}. Otherwise the content of {@link #UNKNOWN_REQUEST_COUNT} is
     * returned.
     * </p>
     */
    @Override
    public Long getUnknownHttpRequestsCount() throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return UNKNOWN_REQUEST_COUNT;
        }
    }

    /**
     * {@inheritDoc}
     * 
     * <p>
     * Mock dedicated processing: If the component name is {@value #IDENTIFIER_FOR_COMPONENT_WITH_ERROR} the exception
     * {@link ComponentMonitoringServiceErrorException} is thrown with the message
     * {@value #ERROR_MESSAGE_GETTING_MONITORING_VALUES}. Otherwise the content of
     * {@link #SERVICE_CONTRACTS_REQUEST_COUNT} is returned.
     * </p>
     */
    @Override
    public Map<String, Long> getServiceContractsHttpRequestsCount() throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return SERVICE_CONTRACTS_REQUEST_COUNT;
        }
    }

    @Override
    public Map<IncomingWsRequestKey, Long[]> getIncomingWsRequestsResponseTimes()
            throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return INCOMING_WS_REQUEST_RESPONSE_TIMES;
        }
    }

    @Override
    public Map<IncomingWsRequestKey, Long[]> getIncomingWsRequestsResponseTimesGroupedBySvcAndExecStatus()
            throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return INCOMING_WS_REQUEST_RESPONSE_TIMES_GRP_BY_SVC_AND_STATUS;
        }
    }

    /**
     * {@inheritDoc}
     * 
     * <p>
     * Mock dedicated processing: If the component name is {@value #IDENTIFIER_FOR_COMPONENT_WITH_ERROR} the exception
     * {@link ComponentMonitoringServiceErrorException} is thrown with the message
     * {@value #ERROR_MESSAGE_GETTING_MONITORING_VALUES}. Otherwise the content of following values are returned:
     * <ul>
     * <li>{@link #HTTP_SERVER_THREAD_POOL_MIN_SIZE},</li>
     * <li>{@link #HTTP_SERVER_THREAD_POOL_MAX_SIZE},</li>
     * <li>{@link #HTTP_SERVER_THREAD_POOL_ACTIVE_THREAD_CURRENT},</li>
     * <li>{@link #HTTP_SERVER_THREAD_POOL_ACTIVE_THREAD_MAX},</li>
     * <li>{@link #HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT},</li>
     * <li>{@link #HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX},</li>
     * <li>{@link #HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT},</li>
     * <li>{@link #HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX},</li>
     * </ul>
     * </p>
     */
    @Override
    public ThreadPoolMetrics getHttpServerThreadPoolMetrics() throws ComponentMonitoringServiceErrorException {

        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {

            return new ThreadPoolMetricsMock(HTTP_SERVER_THREAD_POOL_MIN_SIZE, HTTP_SERVER_THREAD_POOL_MAX_SIZE,
                    HTTP_SERVER_THREAD_POOL_ACTIVE_THREAD_CURRENT, HTTP_SERVER_THREAD_POOL_ACTIVE_THREAD_MAX,
                    HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT, HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX,
                    HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT, HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX);
        }
    }

    @Override
    public Map<WsClientPoolKey, Long> getWsClientPoolClientsInUseMax() throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return null;
        }
    }

    @Override
    public Map<WsClientPoolKey, Long> getWsClientPoolClientsInUseCurrent()
            throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return null;
        }
    }

    @Override
    public Map<WsClientPoolKey, Long> getWsClientPoolExhaustions() throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return null;
        }
    }

    /**
     * {@inheritDoc}
     * 
     * <p>
     * Mock dedicated processing: If the component name is {@value #IDENTIFIER_FOR_COMPONENT_WITH_ERROR} the exception
     * {@link ComponentMonitoringServiceErrorException} is thrown with the message
     * {@value #ERROR_MESSAGE_GETTING_MONITORING_VALUES}. Otherwise the content of {@link #OUTGOING_WS_REQUEST_COUNT} is
     * returned.
     * </p>
     */
    @Override
    public Map<OutgoingWsRequestKey, Long> getOutgoingWsRequestsCount()
            throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return OUTGOING_WS_REQUEST_COUNT;
        }
    }

    @Override
    public Map<OutgoingWsRequestKey, Long[]> getOutgoingWsRequestsResponseTimes()
            throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return OUTGOING_WS_REQUEST_RESPONSE_TIMES;
        }
    }

    @Override
    public Map<OutgoingWsRequestKey, Long[]> getOutgoingWsRequestsResponseTimesGroupedBySvcAndExecStatus()
            throws ComponentMonitoringServiceErrorException {
        if (IDENTIFIER_FOR_COMPONENT_WITH_ERROR.equals(componentName)) {
            throw new ComponentMonitoringServiceErrorException(ERROR_MESSAGE_GETTING_MONITORING_VALUES);
        } else {
            return OUTGOING_WS_REQUEST_RESPONSE_TIMES_GRP_BY_SVC_AND_STATUS;
        }
    }

    @Override
    public ThreadPoolMetrics getMexProcessorThreadPoolMetrics() throws ComponentMonitoringServiceErrorException {
        // TODO Auto-generated method stub
        return null;
    }

}
